@@ -3,7 +3,6 @@
 // Copyright (c) Contributors to the OpenEXR Project.
 //
 
-
 #ifndef INCLUDED_IMF_HEADER_H
 #define INCLUDED_IMF_HEADER_H
 
@@ -15,45 +14,43 @@
 
 #include "ImfForward.h"
 
-#include "ImfLineOrder.h"
+#include "IexBaseExc.h"
+#include "ImathBox.h"
+#include "ImathVec.h"
 #include "ImfCompression.h"
+#include "ImfLineOrder.h"
 #include "ImfName.h"
 #include "ImfTileDescription.h"
-#include "ImathVec.h"
-#include "ImathBox.h"
-#include "IexBaseExc.h"
 
 #include "ImfAttribute.h"
 
-#include <map>
-#include <iosfwd>
-#include <string>
 #include <cstdint>
-
+#include <iosfwd>
+#include <map>
+#include <string>
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
 
 using std::string;
 
-
 class IMF_EXPORT_TYPE Header
 {
-  public:
-    
+public:
     //----------------------------------------------------------------
     // Default constructor -- the display window and the data window
     // are both set to Box2i (V2i (0, 0), V2i (width-1, height-1).
     //----------------------------------------------------------------
 
     IMF_EXPORT
-    Header (int width = 64,
-	    int height = 64,
-	    float pixelAspectRatio = 1,
-	    const IMATH_NAMESPACE::V2f &screenWindowCenter = IMATH_NAMESPACE::V2f (0, 0),
-	    float screenWindowWidth = 1,
-	    LineOrder lineOrder = INCREASING_Y,
-	    Compression = ZIP_COMPRESSION);
-
+    Header (
+        int                         width            = 64,
+        int                         height           = 64,
+        float                       pixelAspectRatio = 1,
+        const IMATH_NAMESPACE::V2f& screenWindowCenter =
+            IMATH_NAMESPACE::V2f (0, 0),
+        float     screenWindowWidth = 1,
+        LineOrder lineOrder         = INCREASING_Y,
+        Compression                 = ZIP_COMPRESSION);
 
     //--------------------------------------------------------------------
     // Constructor -- the data window is specified explicitly; the display
@@ -61,15 +58,16 @@ class IMF_EXPORT_TYPE Header
     //--------------------------------------------------------------------
 
     IMF_EXPORT
-    Header (int width,
-	    int height,
-	    const IMATH_NAMESPACE::Box2i &dataWindow,
-	    float pixelAspectRatio = 1,
-	    const IMATH_NAMESPACE::V2f &screenWindowCenter = IMATH_NAMESPACE::V2f (0, 0),
-	    float screenWindowWidth = 1,
-	    LineOrder lineOrder = INCREASING_Y,
-	    Compression = ZIP_COMPRESSION);
-
+    Header (
+        int                           width,
+        int                           height,
+        const IMATH_NAMESPACE::Box2i& dataWindow,
+        float                         pixelAspectRatio = 1,
+        const IMATH_NAMESPACE::V2f&   screenWindowCenter =
+            IMATH_NAMESPACE::V2f (0, 0),
+        float     screenWindowWidth = 1,
+        LineOrder lineOrder         = INCREASING_Y,
+        Compression                 = ZIP_COMPRESSION);
 
     //----------------------------------------------------------
     // Constructor -- the display window and the data window are
@@ -77,14 +75,15 @@ class IMF_EXPORT_TYPE Header
     //----------------------------------------------------------
 
     IMF_EXPORT
-    Header (const IMATH_NAMESPACE::Box2i &displayWindow,
-	    const IMATH_NAMESPACE::Box2i &dataWindow,
-	    float pixelAspectRatio = 1,
-	    const IMATH_NAMESPACE::V2f &screenWindowCenter = IMATH_NAMESPACE::V2f (0, 0),
-	    float screenWindowWidth = 1,
-	    LineOrder lineOrder = INCREASING_Y,
-	    Compression = ZIP_COMPRESSION);
-
+    Header (
+        const IMATH_NAMESPACE::Box2i& displayWindow,
+        const IMATH_NAMESPACE::Box2i& dataWindow,
+        float                         pixelAspectRatio = 1,
+        const IMATH_NAMESPACE::V2f&   screenWindowCenter =
+            IMATH_NAMESPACE::V2f (0, 0),
+        float     screenWindowWidth = 1,
+        LineOrder lineOrder         = INCREASING_Y,
+        Compression                 = ZIP_COMPRESSION);
 
     //-----------------
     // Copy constructor
@@ -102,7 +101,6 @@ class IMF_EXPORT_TYPE Header
     IMF_EXPORT
     ~Header ();
 
-
     //-----------
     // Assignment
     //-----------
@@ -131,12 +129,10 @@ class IMF_EXPORT_TYPE Header
     //---------------------------------------------------------------
 
     IMF_EXPORT
-    void			insert (const char name[],
-				        const Attribute &attribute);
+    void insert (const char name[], const Attribute& attribute);
 
     IMF_EXPORT
-    void			insert (const std::string &name,
-				        const Attribute &attribute);
+    void insert (const std::string& name, const Attribute& attribute);
 
     //---------------------------------------------------------------
     // Remove an attribute:
@@ -150,12 +146,10 @@ class IMF_EXPORT_TYPE Header
     //---------------------------------------------------------------
 
     IMF_EXPORT
-    void                        erase (const char name[]);
+    void erase (const char name[]);
     IMF_EXPORT
-    void                        erase (const std::string &name);
+    void erase (const std::string& name);
 
-    
-    
     //------------------------------------------------------------------
     // Access to existing attributes:
     //
@@ -177,101 +171,100 @@ class IMF_EXPORT_TYPE Header
     //------------------------------------------------------------------
 
     IMF_EXPORT
-    Attribute &			operator [] (const char name[]);
+    Attribute& operator[] (const char name[]);
     IMF_EXPORT
-    const Attribute &		operator [] (const char name[]) const;
+    const Attribute& operator[] (const char name[]) const;
 
     IMF_EXPORT
-    Attribute &			operator [] (const std::string &name);
+    Attribute& operator[] (const std::string& name);
     IMF_EXPORT
-    const Attribute &		operator [] (const std::string &name) const;
+    const Attribute& operator[] (const std::string& name) const;
 
-    template <class T> T&	typedAttribute (const char name[]);
-    template <class T> const T&	typedAttribute (const char name[]) const;
+    template <class T> T&       typedAttribute (const char name[]);
+    template <class T> const T& typedAttribute (const char name[]) const;
 
-    template <class T> T&	typedAttribute (const std::string &name);
-    template <class T> const T&	typedAttribute (const std::string &name) const;
+    template <class T> T&       typedAttribute (const std::string& name);
+    template <class T> const T& typedAttribute (const std::string& name) const;
 
-    template <class T> T*	findTypedAttribute (const char name[]);
-    template <class T> const T*	findTypedAttribute (const char name[]) const;
+    template <class T> T*       findTypedAttribute (const char name[]);
+    template <class T> const T* findTypedAttribute (const char name[]) const;
 
-    template <class T> T*	findTypedAttribute (const std::string &name);
-    template <class T> const T*	findTypedAttribute (const std::string &name)
-								       const;
+    template <class T> T* findTypedAttribute (const std::string& name);
+    template <class T>
+    const T* findTypedAttribute (const std::string& name) const;
 
     //---------------------------------------------
     // Iterator-style access to existing attributes
     //---------------------------------------------
 
-    typedef std::map <Name, Attribute *> AttributeMap;
+    typedef std::map<Name, Attribute*> AttributeMap;
 
     class Iterator;
     class ConstIterator;
 
     IMF_EXPORT
-    Iterator			begin ();
+    Iterator begin ();
     IMF_EXPORT
-    ConstIterator		begin () const;
+    ConstIterator begin () const;
 
     IMF_EXPORT
-    Iterator			end ();
+    Iterator end ();
     IMF_EXPORT
-    ConstIterator		end () const;
+    ConstIterator end () const;
 
     IMF_EXPORT
-    Iterator			find (const char name[]);
+    Iterator find (const char name[]);
     IMF_EXPORT
-    ConstIterator		find (const char name[]) const;
+    ConstIterator find (const char name[]) const;
 
     IMF_EXPORT
-    Iterator			find (const std::string &name);
+    Iterator find (const std::string& name);
     IMF_EXPORT
-    ConstIterator		find (const std::string &name) const;
-
+    ConstIterator find (const std::string& name) const;
 
     //--------------------------------
     // Access to predefined attributes
     //--------------------------------
 
     IMF_EXPORT
-    IMATH_NAMESPACE::Box2i &		displayWindow ();
+    IMATH_NAMESPACE::Box2i& displayWindow ();
     IMF_EXPORT
-    const IMATH_NAMESPACE::Box2i &	displayWindow () const;
+    const IMATH_NAMESPACE::Box2i& displayWindow () const;
 
     IMF_EXPORT
-    IMATH_NAMESPACE::Box2i &		dataWindow ();
+    IMATH_NAMESPACE::Box2i& dataWindow ();
     IMF_EXPORT
-    const IMATH_NAMESPACE::Box2i &	dataWindow () const;
+    const IMATH_NAMESPACE::Box2i& dataWindow () const;
 
     IMF_EXPORT
-    float &			pixelAspectRatio ();
+    float& pixelAspectRatio ();
     IMF_EXPORT
-    const float &		pixelAspectRatio () const;
+    const float& pixelAspectRatio () const;
 
     IMF_EXPORT
-    IMATH_NAMESPACE::V2f &		screenWindowCenter ();
+    IMATH_NAMESPACE::V2f& screenWindowCenter ();
     IMF_EXPORT
-    const IMATH_NAMESPACE::V2f &		screenWindowCenter () const;
+    const IMATH_NAMESPACE::V2f& screenWindowCenter () const;
 
     IMF_EXPORT
-    float &			screenWindowWidth ();
+    float& screenWindowWidth ();
     IMF_EXPORT
-    const float &		screenWindowWidth () const;
+    const float& screenWindowWidth () const;
 
     IMF_EXPORT
-    ChannelList &		channels ();
+    ChannelList& channels ();
     IMF_EXPORT
-    const ChannelList &		channels () const;
+    const ChannelList& channels () const;
 
     IMF_EXPORT
-    LineOrder &			lineOrder ();
+    LineOrder& lineOrder ();
     IMF_EXPORT
-    const LineOrder &		lineOrder () const;
+    const LineOrder& lineOrder () const;
 
     IMF_EXPORT
-    Compression &		compression ();
+    Compression& compression ();
     IMF_EXPORT
-    const Compression &		compression () const;
+    const Compression& compression () const;
 
     //-----------------------------------------------------
     // The header object allows one to store a compression level to be
@@ -299,65 +292,63 @@ class IMF_EXPORT_TYPE Header
     // for multipart files.
     //-----------------------------------------------------
     IMF_EXPORT
-    void                        setName (const string& name);
+    void setName (const string& name);
 
     IMF_EXPORT
-    string&                     name();
+    string& name ();
     IMF_EXPORT
-    const string&               name() const;
+    const string& name () const;
 
     IMF_EXPORT
-    bool                        hasName() const;
+    bool hasName () const;
 
     IMF_EXPORT
-    void                        setType (const string& Type);
+    void setType (const string& Type);
 
     IMF_EXPORT
-    string&                     type();
+    string& type ();
     IMF_EXPORT
-    const string&               type() const;
+    const string& type () const;
 
     IMF_EXPORT
-    bool                        hasType() const;
+    bool hasType () const;
 
     IMF_EXPORT
-    void                        setVersion (const int version);
+    void setVersion (const int version);
 
     IMF_EXPORT
-    int&                        version();
+    int& version ();
     IMF_EXPORT
-    const int&                  version() const;
+    const int& version () const;
 
     IMF_EXPORT
-    bool                        hasVersion() const;
+    bool hasVersion () const;
 
     //
     // the chunkCount attribute is set automatically when a file is written.
     // There is no need to set it manually
     //
     IMF_EXPORT
-    void                        setChunkCount(int chunks);
+    void setChunkCount (int chunks);
     IMF_EXPORT
-    bool                        hasChunkCount() const;
+    bool hasChunkCount () const;
     IMF_EXPORT
-    const int &                 chunkCount() const;
+    const int& chunkCount () const;
     IMF_EXPORT
-    int &                       chunkCount();
+    int& chunkCount ();
 
-    
     //
     // for multipart files, return whether the file has a view string attribute
     // (for the deprecated single part multiview format EXR, see ImfMultiView.h)
     //
     IMF_EXPORT
-    void                       setView(const string & view);
+    void setView (const string& view);
     IMF_EXPORT
-    bool                       hasView() const;
+    bool hasView () const;
     IMF_EXPORT
-    string &                   view();
+    string& view ();
     IMF_EXPORT
-    const string &             view() const;
-    
+    const string& view () const;
 
     //----------------------------------------------------------------------
     // Tile Description:
@@ -381,16 +372,15 @@ class IMF_EXPORT_TYPE Header
     //----------------------------------------------------------------------
 
     IMF_EXPORT
-    void			setTileDescription (const TileDescription & td);
+    void setTileDescription (const TileDescription& td);
 
     IMF_EXPORT
-    TileDescription &		tileDescription ();
+    TileDescription& tileDescription ();
     IMF_EXPORT
-    const TileDescription &	tileDescription () const;
+    const TileDescription& tileDescription () const;
 
     IMF_EXPORT
-    bool			hasTileDescription() const;
-
+    bool hasTileDescription () const;
 
     //----------------------------------------------------------------------
     // Preview image:
@@ -414,38 +404,35 @@ class IMF_EXPORT_TYPE Header
     //----------------------------------------------------------------------
 
     IMF_EXPORT
-    void			setPreviewImage (const PreviewImage &p);
+    void setPreviewImage (const PreviewImage& p);
 
     IMF_EXPORT
-    PreviewImage &		previewImage ();
+    PreviewImage& previewImage ();
     IMF_EXPORT
-    const PreviewImage &	previewImage () const;
+    const PreviewImage& previewImage () const;
 
     IMF_EXPORT
-    bool			hasPreviewImage () const;
-
+    bool hasPreviewImage () const;
 
     //-------------------------------------------------------------
     // Sanity check -- examines the header, and throws an exception
     // if it finds something wrong (empty display window, negative
-    // pixel aspect ratio, unknown compression sceme etc.)
+    // pixel aspect ratio, unknown compression scheme etc...)
     //
     // set isTiled to true if you are checking a tiled/multi-res
     // header
     //-------------------------------------------------------------
 
     IMF_EXPORT
-    void			sanityCheck (bool isTiled = false,
-        			             bool isMultipartFile = false) const;
-
+    void sanityCheck (bool isTiled = false, bool isMultipartFile = false) const;
 
     //----------------------------------------------------------------
-    // Maximum image size and maximim tile size:
+    // Maximum image size and maximum tile size:
     //
     // sanityCheck() will throw an exception if the width or height of
     // the data window exceeds the maximum image width or height, or
     // if the size of a tile exceeds the maximum tile width or height.
-    // 
+    //
     // At program startup the maximum image and tile width and height
     // are set to zero, meaning that width and height are unlimited.
     //
@@ -456,16 +443,20 @@ class IMF_EXPORT_TYPE Header
     //----------------------------------------------------------------
 
     IMF_EXPORT
-    static void			setMaxImageSize (int maxWidth, int maxHeight);
+    static void setMaxImageSize (int maxWidth, int maxHeight);
     IMF_EXPORT
-    static void			setMaxTileSize (int maxWidth, int maxHeight);
+    static void setMaxTileSize (int maxWidth, int maxHeight);
+    IMF_EXPORT
+    static void getMaxImageSize (int& maxWidth, int& maxHeight);
+    IMF_EXPORT
+    static void getMaxTileSize (int& maxWidth, int& maxHeight);
+
 
     //
     // Check if the header reads nothing.
     //
     IMF_EXPORT
-    bool                        readsNothing();
-
+    bool readsNothing ();
 
     //------------------------------------------------------------------
     // Input and output:
@@ -477,15 +468,13 @@ class IMF_EXPORT_TYPE Header
     // returns 0.
     //------------------------------------------------------------------
 
+    IMF_EXPORT
+    uint64_t writeTo (
+        OPENEXR_IMF_INTERNAL_NAMESPACE::OStream& os,
+        bool                                     isTiled = false) const;
 
     IMF_EXPORT
-    uint64_t			writeTo (OPENEXR_IMF_INTERNAL_NAMESPACE::OStream &os,
-					 bool isTiled = false) const;
-
-    IMF_EXPORT
-    void			readFrom (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is,
-        			          int &version);
-    
+    void readFrom (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream& is, int& version);
 
 private:
     AttributeMap _map;
@@ -493,68 +482,61 @@ private:
     bool _readsNothing;
 };
 
-
 //----------
 // Iterators
 //----------
 
 class IMF_EXPORT_TYPE Header::Iterator
 {
-  public:
-
+public:
     IMF_EXPORT
     Iterator ();
     IMF_EXPORT
-    Iterator (const Header::AttributeMap::iterator &i);
+    Iterator (const Header::AttributeMap::iterator& i);
 
     IMF_EXPORT
-    Iterator &			operator ++ ();
+    Iterator& operator++ ();
     IMF_EXPORT
-    Iterator 			operator ++ (int);
+    Iterator operator++ (int);
 
     IMF_EXPORT
-    const char *		name () const;
+    const char* name () const;
     IMF_EXPORT
-    Attribute &			attribute () const;
-
-  private:
+    Attribute& attribute () const;
 
+private:
     friend class Header::ConstIterator;
 
     Header::AttributeMap::iterator _i;
 };
 
-
 class IMF_EXPORT_TYPE Header::ConstIterator
 {
-  public:
-
+public:
     IMF_EXPORT
     ConstIterator ();
     IMF_EXPORT
-    ConstIterator (const Header::AttributeMap::const_iterator &i);
+    ConstIterator (const Header::AttributeMap::const_iterator& i);
     IMF_EXPORT
-    ConstIterator (const Header::Iterator &other);
+    ConstIterator (const Header::Iterator& other);
 
     IMF_EXPORT
-    ConstIterator &		operator ++ ();
+    ConstIterator& operator++ ();
     IMF_EXPORT
-    ConstIterator 		operator ++ (int);
+    ConstIterator operator++ (int);
 
     IMF_EXPORT
-    const char *		name () const;
+    const char* name () const;
     IMF_EXPORT
-    const Attribute &		attribute () const;
+    const Attribute& attribute () const;
 
-  private:
-
-    friend bool operator == (const ConstIterator &, const ConstIterator &);
-    friend bool operator != (const ConstIterator &, const ConstIterator &);
+private:
+    friend bool operator== (const ConstIterator&, const ConstIterator&);
+    friend bool operator!= (const ConstIterator&, const ConstIterator&);
 
     Header::AttributeMap::const_iterator _i;
 };
 
-
 //------------------------------------------------------------------------
 // Library initialization:
 //
@@ -571,205 +553,177 @@ class IMF_EXPORT_TYPE Header::ConstIterator
 
 IMF_EXPORT void staticInitialize ();
 
-
 //-----------------
 // Inline Functions
 //-----------------
 
-
-inline
-Header::Iterator::Iterator (): _i()
+inline Header::Iterator::Iterator () : _i ()
 {
     // empty
 }
 
-
-inline
-Header::Iterator::Iterator (const Header::AttributeMap::iterator &i): _i (i)
+inline Header::Iterator::Iterator (const Header::AttributeMap::iterator& i)
+    : _i (i)
 {
     // empty
 }
 
-
-inline Header::Iterator &		
-Header::Iterator::operator ++ ()
+inline Header::Iterator&
+Header::Iterator::operator++ ()
 {
     ++_i;
     return *this;
 }
 
-
-inline Header::Iterator 	
-Header::Iterator::operator ++ (int)
+inline Header::Iterator
+Header::Iterator::operator++ (int)
 {
     Iterator tmp = *this;
     ++_i;
     return tmp;
 }
 
-
-inline const char *
+inline const char*
 Header::Iterator::name () const
 {
     return *_i->first;
 }
 
-
-inline Attribute &	
+inline Attribute&
 Header::Iterator::attribute () const
 {
     return *_i->second;
 }
 
-
-inline
-Header::ConstIterator::ConstIterator (): _i()
+inline Header::ConstIterator::ConstIterator () : _i ()
 {
     // empty
 }
 
-inline
-Header::ConstIterator::ConstIterator
-    (const Header::AttributeMap::const_iterator &i): _i (i)
+inline Header::ConstIterator::ConstIterator (
+    const Header::AttributeMap::const_iterator& i)
+    : _i (i)
 {
     // empty
 }
 
-
-inline
-Header::ConstIterator::ConstIterator (const Header::Iterator &other):
-    _i (other._i)
+inline Header::ConstIterator::ConstIterator (const Header::Iterator& other)
+    : _i (other._i)
 {
     // empty
 }
 
-inline Header::ConstIterator &
-Header::ConstIterator::operator ++ ()
+inline Header::ConstIterator&
+Header::ConstIterator::operator++ ()
 {
     ++_i;
     return *this;
 }
 
-
-inline Header::ConstIterator 		
-Header::ConstIterator::operator ++ (int)
+inline Header::ConstIterator
+Header::ConstIterator::operator++ (int)
 {
     ConstIterator tmp = *this;
     ++_i;
     return tmp;
 }
 
-
-inline const char *
+inline const char*
 Header::ConstIterator::name () const
 {
     return *_i->first;
 }
 
-
-inline const Attribute &	
+inline const Attribute&
 Header::ConstIterator::attribute () const
 {
     return *_i->second;
 }
 
-
 inline bool
-operator == (const Header::ConstIterator &x, const Header::ConstIterator &y)
+operator== (const Header::ConstIterator& x, const Header::ConstIterator& y)
 {
     return x._i == y._i;
 }
 
-
 inline bool
-operator != (const Header::ConstIterator &x, const Header::ConstIterator &y)
+operator!= (const Header::ConstIterator& x, const Header::ConstIterator& y)
 {
     return !(x == y);
 }
 
-
 //---------------------
 // Template definitions
 //---------------------
 
 template <class T>
-T &
+T&
 Header::typedAttribute (const char name[])
 {
-    Attribute *attr = &(*this)[name];
-    T *tattr = dynamic_cast <T *> (attr);
+    Attribute* attr  = &(*this)[name];
+    T*         tattr = dynamic_cast<T*> (attr);
 
-    if (tattr == 0)
-	throw IEX_NAMESPACE::TypeExc ("Unexpected attribute type.");
+    if (tattr == 0) throw IEX_NAMESPACE::TypeExc ("Unexpected attribute type.");
 
     return *tattr;
 }
 
-
 template <class T>
-const T &
+const T&
 Header::typedAttribute (const char name[]) const
 {
-    const Attribute *attr = &(*this)[name];
-    const T *tattr = dynamic_cast <const T *> (attr);
+    const Attribute* attr  = &(*this)[name];
+    const T*         tattr = dynamic_cast<const T*> (attr);
 
-    if (tattr == 0)
-	throw IEX_NAMESPACE::TypeExc ("Unexpected attribute type.");
+    if (tattr == 0) throw IEX_NAMESPACE::TypeExc ("Unexpected attribute type.");
 
     return *tattr;
 }
 
-
 template <class T>
-T &
-Header::typedAttribute (const std::string &name)
+T&
+Header::typedAttribute (const std::string& name)
 {
-    return typedAttribute<T> (name.c_str());
+    return typedAttribute<T> (name.c_str ());
 }
 
-
 template <class T>
-const T &
-Header::typedAttribute (const std::string &name) const
+const T&
+Header::typedAttribute (const std::string& name) const
 {
-    return typedAttribute<T> (name.c_str());
+    return typedAttribute<T> (name.c_str ());
 }
 
-
 template <class T>
-T *
+T*
 Header::findTypedAttribute (const char name[])
 {
     AttributeMap::iterator i = _map.find (name);
-    return (i == _map.end())? 0: dynamic_cast <T *> (i->second);
+    return (i == _map.end ()) ? 0 : dynamic_cast<T*> (i->second);
 }
 
-
 template <class T>
-const T *
+const T*
 Header::findTypedAttribute (const char name[]) const
 {
     AttributeMap::const_iterator i = _map.find (name);
-    return (i == _map.end())? 0: dynamic_cast <const T *> (i->second);
+    return (i == _map.end ()) ? 0 : dynamic_cast<const T*> (i->second);
 }
 
-
 template <class T>
-T *
-Header::findTypedAttribute (const std::string &name)
+T*
+Header::findTypedAttribute (const std::string& name)
 {
-    return findTypedAttribute<T> (name.c_str());
+    return findTypedAttribute<T> (name.c_str ());
 }
 
-
 template <class T>
-const T *
-Header::findTypedAttribute (const std::string &name) const
+const T*
+Header::findTypedAttribute (const std::string& name) const
 {
-    return findTypedAttribute<T> (name.c_str());
+    return findTypedAttribute<T> (name.c_str ());
 }
 
-
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_EXIT
 
 #endif
